import ScreenSliceTypes from '@/sliceViewer/Volume/Constants/ScreenSliceTypes';
import ScreenSlice from "@/sliceViewer/Volume/ScreenSlice";
import { SliceData } from "@/sliceViewer/Volume/Volume";
import { fabric } from "fabric";
import Mouse from "./Mouse";
import Viewer from './Viewer';
declare type SliceViewerProps = {
    screenWidth: number;
    screenHeight: number;
    widthSize?: number;
    heightSize?: number;
    width?: number;
    height?: number;
    boundingBox?: Array<Array<number>>;
    onMouseChange: Function;
    onMouseClick?: Function;
    onWheel: Function;
    screenSlice?: ScreenSlice;
    getMouseWheelDepth?: Function;
    viewer: Viewer;
};
declare type InitOptions = {
    screenWidth: number;
    screenHeight: number;
};
declare class SliceViewer {
    canvas: HTMLCanvasElement;
    context: CanvasRenderingContext2D | null;
    type: ScreenSliceTypes;
    fabric: fabric.Canvas | null;
    fabricImages: fabric.Image[];
    fabricLineX: fabric.Line | null;
    fabricLineY: fabric.Line | null;
    screenWidth: number;
    screenHeight: number;
    width: number;
    height: number;
    depthRange: Array<number>;
    boundingBox: Array<Array<number>>;
    mouse: Mouse | null;
    widthSize: number;
    heightSize: number;
    currentSliceIndex: number;
    transForm: any;
    props: SliceViewerProps;
    afterRender: Function | null;
    rendering: boolean;
    initComplete: boolean;
    screenSlice: ScreenSlice;
    filters: Array<any>;
    crosshairs: boolean;
    zoom: any;
    isHidden: boolean;
    constructor(props: SliceViewerProps);
    init: ({ screenWidth, screenHeight }: InitOptions) => void;
    setVolumeSlice: ({ slice, depthRange }: {
        slice: ScreenSlice;
        depthRange: Array<number>;
    }) => void;
    checkMouseCoorInfo: ({ x, y, z }: any) => boolean;
    updateSlice: (sliceDatas: SliceData[], sliceIndex: number, params?: any) => void;
    setFilter: () => void;
    renderFilter: () => void;
    updateSize: (width: number, height: number) => void;
    updateTranform: () => void;
    setViewportTransform: (t: any) => void;
    getStrokeWidth: (width: number) => number;
    getAbsolutePointerByPointer: ({ x, y }: {
        x: any;
        y: any;
    }) => {
        x: number;
        y: number;
    };
    renderLine: (x: number, y: number, forceUpdate: any, afterRender?: Function) => void;
    getXYFromMouse: (e: any) => {
        x: number;
        y: number;
    };
    updateBrightness: (key: number, value: any) => void;
    updateContrast: (key: any, value: any) => void;
    updateAlpha: (index: number, value: number) => void;
    mouseOperation: (e: any) => void;
    zoomToPoint: ({ x, y, value }: {
        x: number;
        y: number;
        value?: number;
    }) => void;
    tranform: ({ x, y }: {
        x: number;
        y: number;
    }) => void;
    zoomToPointByLoc: ({ x, y, value }: {
        x: number;
        y: number;
        value?: number;
    }) => void;
    addMouseEventHandler: () => void;
    reset: () => void;
    setIsHidden: (isHidden: any) => void;
    getIsHidden: () => boolean;
}
export default SliceViewer;
