import ImageRange from '@/sliceViewer/Volume/ImageRange';
import { ColorMapHandlerModel } from './../Volume/ColorMapHandler';
import Volume from "@/sliceViewer/Volume/Volume";
import { CoordinateSystem } from '@/sliceViewer/Volume/NiftiHandler';
import Screen from "./Screen";
import SliceViewer from "./SliceViewer";
import ScreenSliceTypes from "@/sliceViewer/Volume/Constants/ScreenSliceTypes";
import LayoutConstant from "./LayoutConstant";
import MouseEvent, { CLICK_WAY, EVENT_Model } from '@/sliceViewer/Viewer/Handler/MouseEvent';
export declare enum MRPModel {
    CROSSHAIRS = 0,
    WWWC = 1,
    ZOOM = 2,
    STACK = 3,
    MOVE = 4
}
export interface ViewerProps {
}
declare type ViewerConstructorProps = {
    /**
    * @description       viewer容器挂载的Id
    */
    containerId: string;
    /**
   * @description      sliceViewer更新时渲染的回调
   */
    updateViewCallback?: Function;
    /**
   * @description      鼠标事件触发时的回调，鼠标滑动时，默认会触发防抖事件
   */
    onMouseChange?: Function;
    /**
  * @description     slice Div的样式
  */
    sliceStyle?: CSSStyleDeclaration;
    /**
    * @description      鼠标事件触发时的回调，鼠标滑动时，不会触发防抖
    */
    onMouseChangeImmediately?: Function;
    /**
   * @description    布局方式
   */
    layout?: LayoutConstant;
    /**
    * @description    屏幕初始化完成的回调函数
    */
    screenInitFinished?: Function;
    /**
     * @description    坐标系
     */
    coordinateSystem?: CoordinateSystem;
    /**
     *@description    布局索引
     */
    layoutOrder?: Array<string>;
    /**
   * @description    自定义页面宽度计算方式
   */
    customCalculateSize?: ({ width, height, type, parentWidth, parentHeight, }: {
        width: any;
        height: any;
        type: any;
        parentWidth: any;
        parentHeight: any;
    }) => ({
        width: number;
        height: number;
        style: CSSStyleDeclaration;
    });
    /**
     *@description   向screen插入slice过程的回调函数,接受一个数组，来表明插入的处理过程
     */
    sliceDomRender?: Array<Function>;
    /**
     *@description 鼠标点击事件的回调,鼠标(按下的回调)
     */
    onMouseClick?: ({ x, y, z }: {
        x: number;
        y: number;
        z: number;
    }) => {};
    /**
    * @description      当鼠标模式为标尺获取的相关事件信息
    */
    onMouseRulerChange?: Function;
};
declare type UnderLayInfoOptions = {
    key?: string;
    colorMap?: any;
    colorMapModel?: any;
    coordinateSystem?: CoordinateSystem;
    useNN?: boolean;
    useDefaultImageRange?: boolean;
};
declare class Viewer implements ViewerProps {
    props: ViewerConstructorProps;
    containerId: string;
    containerDom: HTMLElement | null;
    width: number;
    height: number;
    resizeTime: any;
    mainScreen: Screen;
    topScreen: Screen;
    bottomScreen: Screen;
    axialSlice: SliceViewer;
    coronalSlice: SliceViewer;
    sagittalSlice: SliceViewer;
    eventLoading: any;
    volumeMap: Map<string, Volume>;
    rendering: any;
    sliceViewerModel: MRPModel;
    mouseEvent: MouseEvent;
    coordinateSystem: CoordinateSystem;
    layoutOrder: Array<string>;
    x: number;
    y: number;
    z: number;
    mouseWheelDepth: number;
    constructor(props: ViewerConstructorProps);
    init: () => void;
    screenInit: () => void;
    sliceInit: () => void;
    onMouseChange: (x: number, y: number, z: number, event: any, screenSliceTypes?: ScreenSliceTypes) => void;
    onMouseClick: (x: number, y: number, z: number) => void;
    onWheel: (x: number, y: number, z: number) => void;
    propsOnMouseChange: () => void;
    getCoordInfo: (volumeKey?: string) => {
        x: number;
        y: number;
        z: number;
        i: any;
        j: any;
        k: any;
        value: number;
    }[] | {
        x: number;
        y: number;
        z: number;
        i: any;
        j: any;
        k: any;
        value: number;
    };
    resize: () => void;
    eventListener: () => void;
    loadVolume: (volume: any, config: any) => Promise<unknown>;
    loadUnderlayNiftiFile: (niftiFile: File, config: UnderLayInfoOptions) => Promise<unknown>;
    underlayNiftiInit: (underlayNifti: Volume) => {
        axialSlice: boolean;
        coronalSlice: boolean;
        sagittalSlice: boolean;
    };
    loadOverlayNiftiFile: (niftiFile: File, config: any) => Promise<unknown>;
    clear: () => void;
    getBaseVolumnOrigin: () => {
        x: number;
        y: number;
        z: number;
    };
    getExtraSlice: (data: any) => any;
    updateSlice: (x: number, y: number, z: number, force: boolean) => void;
    updateLine: (x: number, y: number, z: number, forceUpdate?: boolean, beforeUpdate?: Function) => void;
    update: () => void;
    /**
     * 该方法不会应发鼠标事件回调，只会根据需要渲染当前视图
     * @param param0
     */
    updateCoorInfo: ({ x, y, z }: any) => void;
    updateCoorInfoByIJK: ({ i, j, k }: any, key?: string) => void;
    hiddenVolumeByKey: (key: string) => void;
    showVolumeByKey: (key: string) => void;
    hiddenVolume: (volume: Volume) => void;
    showVolume: (volume: Volume) => void;
    getVolumeByKey: (key: string) => Volume;
    getVolumeInfo: (key: string) => void;
    updateImageRangeByKey: (key: string, value: any) => void;
    updateNegImageRangeByKey: (key: string, value: any) => void;
    updatePosImageRangeByKey: (key: string, value: any) => void;
    updateColorMapByKey: (key: string, value: any) => void;
    updateTimePointByKey: (key: string, value: any) => void;
    resetImageFilterByKey: (key: string) => void;
    getIndexByKey: (targetKey: string) => number;
    updateAlphaByKey: (targetKey: string, value: any) => void;
    updateBrightness: (targetKey: string, value: any) => void;
    updateContrast: (targetKey: string, value: any) => void;
    updateLayout: (layout: LayoutConstant) => void;
    updateLayoutOrder: (layout: string[]) => void;
    setEventHandler: (clickWay: CLICK_WAY, eventModel: EVENT_Model) => void;
    updateCoordinateSystem: (coordinateSystem: CoordinateSystem) => void;
    sliceZoom: ({ value, screenSliceTypes }: {
        value: any;
        screenSliceTypes: any;
    }) => void;
    setSliceCrosshairs: (isvisitable: any) => void;
    updateColorMapModel: (key: string, colorMapModel: ColorMapHandlerModel) => void;
    /**
     * 重置Volume imageRange
     *
     */
    reset: () => void;
    getVolumeInfoByKey: (key: string) => {
        imageDescription: number[];
        voxelDimensions: number[];
        affine: number[][];
        bandbox: number[][];
        colorMap: void;
        imageRange: ImageRange;
        timePointOfNumber: number;
        dataType: string;
        fileName: string;
    };
    rulerChange: (params: any) => void;
    setMouseWheelDepth: (mouseWheelDepth: number) => void;
    getMouseWheelDepth: () => number;
    getBaseVolume: () => Volume;
}
export default Viewer;
