import HeaderType from '@/sliceViewer/Volume/Constants/HeaderType';
import ImageRange from '@/sliceViewer/Volume/ImageRange';
import ImageType from '@/sliceViewer/Volume/ImageType';
import { Matrix } from 'mathjs';
import ImageDimensions from './ImageDimensions';
import VoxelDimensions from './VoxelDimensions';
import Coordinate from './coordinate';
import ImageDatas from './ImageDatas';
export declare type Increments = {
    xIncrement: number;
    yIncrement: number;
    zIncrement: number;
};
export declare type UnderLayInfo = {
    boundingBoxMatrix?: Matrix;
    voxSizesMatrix?: Matrix;
    dimsMatrix?: Matrix;
};
export declare enum CoordinateSystem {
    VOXEL = 0,
    MNI = 1
}
declare class NiftiHandler {
    headerType: HeaderType;
    dimsArray: Array<number>;
    voxSizesArray: Array<number>;
    affineArray: Array<Array<number>> | any;
    invAffineArray: Array<Array<number>> | any;
    boundingBoxArray: Array<Array<number>> | any;
    imageDescription: String;
    imageType: ImageType | null;
    imageRange: ImageRange | null;
    imageData: ImageDatas | null;
    imageDimensions: ImageDimensions | null;
    voxelDimensions: VoxelDimensions | null;
    xDim: number;
    yDim: number;
    zDim: number;
    error: String;
    origin: any;
    nifti: any;
    MNIAffineArray: Array<Array<number>> | any;
    MNIINVAffineArray: Array<Array<number>> | any;
    compressed: boolean;
    isNIFTI2: boolean;
    data: any;
    imageOneVolume: Array<Array<Array<number>>>;
    TP: number;
    ext: any;
    coordinateSystem: CoordinateSystem;
    props: any;
    constructor(props?: any);
    handleNifitData: (fileName: String, data: any) => void;
    readerBaseImageData: (filename: String, data: any) => void;
    findHeaderType: (fileName: String, data: ArrayBuffer) => HeaderType;
    handleHeaderData: () => void;
    setCoordinateSystem: (coordinateSystem: CoordinateSystem) => void;
    /**
     * 根据当前对象dims值以及一维imageData生成3维model数组
     */
    handleImageData: () => void;
    /**
     * 生成ImageOneVolume,并计算image max和min
     */
    generateImageOneVolume: () => void;
    handleImageDataBeforeGenerateImageOneVolume: (buffer: any) => any;
    /**
     * 根据下角标获取偏移量
     * @param i
     * @param j
     * @param k
     */
    convertIndexToOffset: (i: number, j: number, k: number) => number;
    /**
     * 根据偏移量获取Voxel值 虚数
     *    * @param offset 偏移量
     */
    getImaginaryVoxelAtOffset: (offset: number, dataArray: any) => number;
    calculateAffine: () => any | null;
    calculateInvAffine: () => import("mathjs").MathArray;
    calculateVoxSize: () => Array<number> | null;
    calculateBoundingBox: () => any;
    /**
     * 创建一个imageRange
        let negMax =0
        let negMin =0
        let posMin = 0
        let posMax = 0*
     */
    createImageRange: (negMin: number, negMax: number, posMin: number, posMax: number) => ImageRange;
    /**
     * 使用nifti头文件中
     */
    createImageRangeByDefault: () => ImageRange;
    getIncrement: () => Increments;
    getImageType: () => ImageType;
    getQformMat: () => any;
    getSformMat: () => any;
    getDims: () => Array<number>;
    getVoxSizes: () => Array<number>;
    getAffine: () => Array<Array<number>> | null;
    getImageModel: () => number[][][];
    getAffineInv: () => Array<Array<number>> | null;
    getBB: () => Array<Array<number>>;
    getXYZ: (i: number, j: number, k: number) => Array<number> | null;
    getXYZByMNIAffine: (i: number, j: number, k: number) => Array<number> | null;
    getIJKByMNIAffine: (x: number, y: number, z: number) => Array<any> | null;
    getIJK: (x: number, y: number, z: number) => Array<any> | null;
    getIoOrientation: (affine: any) => any[];
    /**
     * 获取当前的时间点
     */
    getTimePoint: () => number;
    /**
     * 设置时间点
     * @param TP 时间点
     */
    setTimePoint: (TP: number) => void;
    getImageRange: () => ImageRange;
    qFormHasRotations: () => boolean;
    getOrientationQform: () => string;
    sFormHasRotations: () => boolean;
    getOrientationSform: () => any;
    getOrientation: () => void;
    getOrigin: () => Coordinate;
    updateCoordinateSystem: (coordinateSystem: CoordinateSystem) => void;
}
export default NiftiHandler;
