import ImageRange from '@/sliceViewer/Volume/ImageRange';
import Volume, { SliceData } from '@/sliceViewer/Volume/Volume';
import ScreenSliceTypes from './Constants/ScreenSliceTypes';
import ColorMapHandler from './ColorMapHandler';
import NiftiHandler from './NiftiHandler';
declare type ScreenSliceProps = {
    width: number;
    height: number;
    widthSize: number;
    heightSize: number;
    imageRange: ImageRange | null;
    boundingBoxArray: Array<Array<number>>;
    sliceDirection: ScreenSliceTypes;
    niftiHandler: NiftiHandler;
    colorMapHandler: ColorMapHandler;
    voxelSizes: Array<number>;
    volume: Volume;
};
export default class ScreenSlice {
    width: number;
    height: number;
    widthSize: number;
    heightSize: number;
    screenDisplayMin: number;
    screenDisplayMax: number;
    boundingBoxArray: Array<Array<number>> | null;
    voxelSizes: Array<number>;
    sliceDirection: ScreenSliceTypes;
    volume: Volume;
    canvasMain: HTMLCanvasElement;
    contextMain: CanvasRenderingContext2D;
    colorMapHandler: ColorMapHandler;
    imageDataDraw: ImageData;
    constructor({ width, height, widthSize, heightSize, boundingBoxArray, sliceDirection, volume, colorMapHandler, imageRange, voxelSizes }: ScreenSliceProps);
    init: () => void;
    /**
     *
     * @param slice 需要获取的深度
     * @param boundingBoxArray 边框值，默认boundingBoxArray[1]是最大值边框值，默认boundingBoxArray[0]是最小值
     */
    getSliceImageData: (slice: number) => SliceData | null;
    getSliceImageDataByIndex: (slice: number) => SliceData | null;
    getTransformParameters: (height: number, lower: boolean, factor: number) => number[][];
    setColorMapHandler: (colorMapHandler: ColorMapHandler) => void;
}
export {};
