import ScreenSlice from '@/sliceViewer/Volume/ScreenSlice';
import OverlaySlice from '@/sliceViewer/Volume/OverlaySlice';
import UnderlaySlice from '@/sliceViewer/Volume/UnderlaySlice';
import ColorMapHandler, { ColorMapHandlerModel } from './ColorMapHandler';
import ImageRange from './ImageRange';
import Handler, { CoordinateSystem } from './NiftiHandler';
import ColorMaps from '@/sliceViewer/ColorMap/ColorMaps';
export interface VolumeProps {
    file: File;
    colorMap?: any;
    isOverlay?: boolean;
    colorMapModel?: ColorMapHandlerModel;
    coordinateSystem?: CoordinateSystem;
    underVolume?: Volume;
    useNN?: boolean;
    useDefaultImageRange?: boolean;
    bb?: Array<any>;
}
export declare type SliceData = {
    imageData: ImageData;
    data: Array<Array<number>>;
    canvas: HTMLCanvasElement;
    getTransformParameters: Function;
    bb: Array<Array<number>> | any;
    xSize: number;
    ySize: number;
    isHidden?: boolean;
    name?: string;
};
declare class Volume {
    props: VolumeProps;
    file: File;
    fileName: string;
    compressed: boolean;
    fileLength: Number;
    onFinishedRead: Function;
    rawData: any;
    handler: Handler;
    col: any;
    row: any;
    slices: any;
    axialSlice: ScreenSlice | null;
    sagittalSlice: ScreenSlice | null;
    coronalSlice: ScreenSlice | null;
    longestDim: number | null;
    longestDimSize: number | null;
    shortDim: number | null;
    shortDimSize: number | null;
    colorMap: ColorMaps;
    colorMapHandler: ColorMapHandler | null;
    isOverlay: boolean;
    isHidden: boolean;
    useNN: boolean;
    underVolume?: Volume | null;
    useDefaultImageRange?: boolean;
    constructor(props: VolumeProps);
    init(): Promise<unknown>;
    loadImage: (onFinishedRead: Function) => void;
    readNextFile: (index: number) => void;
    decompress: () => void;
    finishedDecompress: (dataBuffer: ArrayBufferLike) => void;
    readData: () => void;
    initData: () => void;
    getWidthByBoundingBox: (boundingBoxArrays: Array<number>, VoxelSize: number) => number;
    getSliceByParams: (params: any, isOverlay: any) => OverlaySlice | UnderlaySlice;
    /**
     * 生成slice相关实例，根据imageRange生成ColorMap
     */
    initScreenSlice: () => void;
    getIDim: () => number;
    getJDim: () => number;
    getKDim: () => number;
    getISize: () => number;
    getJSize: () => number;
    getKSize: () => number;
    getColorMapHandler: (colorMap: any) => ColorMapHandler;
    /**
     * 获取AxialSlice对象，如果当前对象中没有的话，则创建(水平面)
     */
    getAxialSlice: (sliceIndex: number) => SliceData | null;
    getCoronalSlice: (sliceIndex: number) => SliceData | null;
    getSagittalSlice: (sliceIndex: number) => SliceData | null;
    sliceToRGBA: (slice: ScreenSlice, sliceIndex: number, includeMinFlag: boolean) => SliceData;
    getXYZ: (i: number, j: number, k: number) => number[];
    getIJK: (x: number, y: number, z: number) => any[];
    getDims: () => number[];
    getVoxelSizes: () => number[];
    getAffine: () => number[][];
    getInvAffine: () => number[][];
    getBB: () => Array<Array<number>>;
    setBB: (bb: Array<Array<number>>) => void;
    getColorMap: () => void;
    /**
     * 设置colorMap值
     * @param colorMap
     */
    setColorMap: (colorMap: Array<number | Array<number>>) => void;
    updatePosImageRange: (min: number, max: number) => void;
    updateNegImageRange: (min: number, max: number) => void;
    updateImageRange: (min: number, max: number) => void;
    getTimePoint: () => number;
    setTimePoint: (timepoint: number) => void;
    getVoxelValByIndex: (i: number, j: number, k: number) => number;
    getVoxelIndexRound: (xLoc: number, yLoc: number, zLoc: number) => number;
    /**
     * 根据ijk矩阵从ImageOneVolume获取voxelValue
     * 查看ijk是否为整数，若不是整数，使用差插值算法(最近领插值|线性插值算法)
     * @param ijkMatrix
     */
    getVoxelIndexLinear: (xLoc: number, yLoc: number, zLoc: number) => number;
    /**
     * 根据xyz矩阵从ImageOneVolume获取voxelValue
     * 根据xyz矩阵获取相对应ijk索引，根据ijk索引索取相关的voxelvalue
     * @param ijkMatrix
     */
    getVoxelValByCoord: (x: number, y: number, z: number) => number;
    getVoxelIndex: (xTrans: any, yTrans: any, zTrans: any) => number;
    calcluateLongestDim: () => void;
    calcluateShortestDim: () => void;
    updateColorMapModel: (colorMapModel: ColorMapHandlerModel) => void;
    getAllTimes: () => number;
    reset: () => void;
    updateCoordinateSystem: (coordinateSystem: CoordinateSystem) => void;
    getInfo: () => {
        imageDescription: number[];
        voxelDimensions: number[];
        affine: number[][];
        bandbox: number[][];
        colorMap: void;
        imageRange: ImageRange;
        timePointOfNumber: number;
        dataType: string;
        fileName: string;
    };
    getCoordinateSystem: () => CoordinateSystem;
}
export default Volume;
