import Base64Binary from './base64-binary';
export default class DataArray {
    attributes: any;
    metadata: any;
    transforms: any;
    data: any;
    dataConverted: any;
    base64Binary: Base64Binary;
    constructor();
    /**
     * Returns true if this data array represents a point set.
     * @returns {boolean}
     */
    isPointSet: () => boolean;
    /**
     * Returns true if this data array represents triangle indices.
     * @returns {boolean}
     */
    isTriangles: () => boolean;
    /**
     * Returns true if this data array represents normals.
     * @returns {boolean}
     */
    isNormals: () => boolean;
    isColumnIndexOrder: () => boolean;
    /**
     * Returns true if this data array represents normals.
     * @returns {boolean}
     */
    isColors: () => boolean;
    /**
     * Returns the number of dimensions of this data array.
     * @returns {number}
     */
    getDimensions: () => number;
    /**
     * Returns the number of elements in the specified dimension.
     * @param {number} dimIndex
     * @returns {number}
     */
    getNumElements: (dimIndex: number) => number;
    /**
     * Returns true if this data array represents scalar data.
     * @returns {boolean}
     */
    isScalar: () => boolean;
    /**
     * Returns true if this data array is in triples.
     * @returns {boolean}
     */
    isTriple: () => boolean;
    /**
     * Returns true if this data array is in quads.
     * @returns {boolean}
     */
    isQuad: () => boolean;
    /**
     * Returns true if this data array is encoded in ASCII format.
     * @returns {boolean}
     */
    isAscii: () => boolean;
    /**
     * Returns true if this data array is encoded in Base64 format.
     * @returns {boolean}
     */
    isBase64Binary: () => boolean;
    /**
     * Returns true if this data array is encoded in GZIP-Base64 format.
     * @returns {boolean}
     */
    isGzipBase64Binary: () => boolean;
    /**
     * Returns true if this data array uses Base64 encoding.
     * @returns {boolean}
     */
    isBase64Encoded: () => boolean;
    /**
     * Returns true if the datatype is 32-bit floating point.
     * @returns {boolean}
     */
    isFloat32: () => boolean;
    /**
     * Returns true if the datatype is 32-bit signed integer.
     * @returns {boolean}
     */
    isInt32: () => boolean;
    /**
     * Returns true if the datatype is 8-bit unsigned integer.
     * @returns {boolean}
     */
    isUnsignedInt8: () => boolean;
    /**
     * Returns the data as a typed array (either Float32Array, Uint8Array or Int32Array)
     * @returns {Float32Array|Uint8Array|Int32Array}
     */
    getData: () => any;
    getDataAsync: (onProgress: any, onFinish: Function) => void;
    readFloat32ASCII: (obj: any) => void;
    readSignedInt32ASCII: (obj: any) => void;
    readUnsignedInt8ASCII: (obj: any) => void;
    readUnsignedInt8Base64: (obj: any) => void;
    readSignedInt32Base64: (obj: any) => void;
    readFloat32Base64: (obj: any) => void;
    readUnsignedInt8GZIPBase64: (obj: any) => void;
    readUnsignedInt8GZIPBase64Async: (obj: any, onProgress: any, onFinish: any) => void;
    readSignedInt32GZIPBase64: (obj: any) => void;
    readSignedInt32GZIPBase64Async: (obj: any, onProgress: any, onFinish: Function) => void;
    readFloat32GZIPBase64: (obj: any) => void;
    readFloat32GZIPBase64Async: (obj: any, onProgress: any, onFinish: Function) => void;
    readNext: (inflator: any, rawData: any, index: number, onProgress: any, onFinish: Function) => void;
}
